@@ -481,7 +481,7 @@ class View(ui.ViewFeedback):
         try:
             f = file(fileName, 'w')
         except IOError, e:
-            self.reportError('Unable to save PGN file ' + fileName, str(e))
+            self.game.application.ui.reportError('Unable to save PGN file %s' % fileName, e.args[1])
             return
         
         print 'Saving game ' + repr(self.game.name) + ' to ' + fileName
@@ -687,8 +687,7 @@ class UI(gtkui.GtkUI):
         except KeyError:
             return False
         else:
-            player.read()
-            return True
+            return player.read()
 
     def onGameStart(self, gameName, allowSpectators, duration, white, black):
         """Called by UI"""
@@ -709,7 +708,7 @@ class UI(gtkui.GtkUI):
         try:
             p = chess.pgn.PGN(path, 1)
         except chess.pgn.Error, e:
-            self.reportError('Unable to open PGN file ' + path, str(e))
+            self.reportError('Unable to open PGN file %s' % path, e.description)
             return
         
         # Use the first game
@@ -827,7 +826,7 @@ class Application:
             try:
                 profile = self.__aiProfiles[profileName]
             except KeyError:
-                msg += "AI '" + whiteType + "' is not installed, white player is now human"
+                msg += "AI '%s' is not installed, white player is now human" % profileName
                 player = g.addHumanPlayer(whiteName)
             else:
                 player = g.addAIPlayer(whiteName, profile, level)
@@ -840,7 +839,7 @@ class Application:
             try:
                 profile = self.__aiProfiles[profileName]
             except KeyError:
-                msg += "AI '" + blackType + "' is not installed, black player is now human"
+                msg += "AI '%s' is not installed, black player is now human" % profileName
                 player = g.addHumanPlayer(blackName)
             else:
                 player = g.addAIPlayer(blackName, profile, level)
@@ -1001,20 +1000,24 @@ class Application:
         fname = self.__config.getAutosavePath()
         print 'Auto-saving to ' + fname + '...'
         
-        f = file(fname, 'a')
-        for g in self.__games:
-            # Ignore games that are saved to a file
-            if g.fileName is not None:
-                continue
+        try:
+            f = file(fname, 'a')
+            for g in self.__games:
+                # Ignore games that are saved to a file
+                if g.fileName is not None:
+                    continue
             
-            pgnGame = chess.pgn.PGNGame()
-            g.toPGN(pgnGame)
+                pgnGame = chess.pgn.PGNGame()
+                g.toPGN(pgnGame)
             
-            lines = pgnGame.getLines()
-            for line in lines:
-                f.write(line + '\n')
-            f.write('\n')
-        f.close()
+                lines = pgnGame.getLines()
+                for line in lines:
+                    f.write(line + '\n')
+                f.write('\n')
+            f.close()
+        except IOError, e:
+            # FIXME: This should be in a dialog
+            print 'Unable to autosave to %s: %s' % (fname, str(e))
 
 if __name__ == '__main__':
     app = Application()
