@@ -10,36 +10,36 @@
  * pancho@nuclecu.unam.mx
  *
  */
+
+#ifndef MAHJONGG_H
+#define MAHJONGG_H
+
 #include <gnome.h>
-#include <gdk-pixbuf/gdk-pixbuf.h>
 
-#define MAX_TILES 144
+#include "maps.h"
+
+
 #define MAX_TILES_STR "144"
 
-struct _tilepos {
-	int x;
-	int y;
-	int layer;
-};
-typedef struct _tilepos tilepos;     
-
 extern tilepos *pos;
 
-
 typedef struct _tile tile;
 
-struct _tile{
+struct _tile {
   int type;
   int image;
   int visible;
   int selected;
   int sequence;
   int number;
-  GdkPixbuf *current_image;
-  GdkPixbuf *current_bg;
-  GnomeCanvasItem *canvas_item;
-  GnomeCanvasItem *image_item;
-  GnomeCanvasItem *bg_item;
 };
 
+void tile_event (gint tileno, gint button);
+
+void mahjongg_theme_warning (gchar * message_format);
+
 extern tile tiles[MAX_TILES];
+extern gint paused;
+extern gchar *tileset;
+
+#endif /* MAHJONGG_H */
